##  Managing User Roles with SSO
With SSO, you can manage user roles internally within SAP LeanIX or externally within your IdP. Choose your preferred option when requesting to set up SSO.
Additionally, you can set up Transient users to grant them access to Self-service Portals. For more information, see [Transient Users with SSO](https://help.sap.com/docs/leanix/ea/single-sign-on-sso?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cc8227a441014a371975e4b816f0a__transient-users-with-sso).
